@@ -26,16 +26,21 @@ Options:
 
 """
 
-__version__ = '0.0.4'
+__version__ = '0.0.5'
 
 
-from docopt import docopt
 from getpass import getpass
 from json import dump, load
-from requests import Request, Session
-from requests.exceptions import Timeout
 from sys import stdin
 
+try:
+  from docopt import docopt
+  from requests import Request, Session
+  from requests.exceptions import Timeout
+except ImportError:
+  # probably in setup.py
+  pass
+
 
 class PasteError(Exception):
 
